import tv2ts
#!/usr/bin/python
# coding: UTF-8
# Rec10 TS Recording Tools
# Copyright (C) 2009-2011 Yukikaze
#import sys
import epgdb
import os
import time
import tv2avi
import tv2mkv
import checker
import guess
import auto_process
import install
#import datetime
import rec10d
#import os
#import time
#import n_gram
#import profile
#import epgdb
#import recdblist
#import status
#import chdb
#import checker
#import configreader
#import classify
#import epgdb
#import rec10d
#import recdb
#import tv2mkv
#import tv2avi
#import xml2db
#import guess
#import zenhan
#import auto_process
import datetime
import tv2mp4
import ts2x264
import recque
path = str(os.path.dirname(os.path.abspath(__file__))) + "/"
recpath = "/home/ftpusr/ftp-tmp/Recording/"
ftpusr = "/home/ftpusr/ftp-tmp"
recordedpath = u"/home/ftpusr/ftp-video"
if __name__ == "__main__":
    ""